==> ejc-analysis-impl-3.0.0-20230630.095827-36-sources.jar: com/ejianc/business/analysis/service/impl/SettledProBusinessServiceImpl.java <==
package com.ejianc.business.analysis.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.analysis.bean.UnsettledProBusinessEntity;
import com.ejianc.business.analysis.utils.CommonUtils;
import com.ejianc.business.analysis.vo.SettledProBusinessVO;
import com.ejianc.business.analysis.vo.UnsettledProBusinessVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ComputeUtil;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.analysis.mapper.SettledProBusinessMapper;
import com.ejianc.business.analysis.bean.SettledProBusinessEntity;
import com.ejianc.business.analysis.service.ISettledProBusinessService;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalTime;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.time.temporal.TemporalAdjusters;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 竣工已结算项目商务报表
 *
 * @author generator
 *
 */
@Service("settledProBusinessService")
public class SettledProBusinessServiceImpl extends BaseServiceImpl<SettledProBusinessMapper, SettledProBusinessEntity> implements ISettledProBusinessService{
    @Autowired
    private IOrgApi orgApi;
    @Autowired
    private ISettledProBusinessService settledProBusinessService;
    @Autowired
    private SettledProBusinessMapper settledProBusinessMapper;
    @Override
    public void execute(Integer inAdvanceFlag, String day, List<Long> projectIdList) {
        //获取查询数据的截止时间
        String reportingMonth = CommonUtils.getEndDate(inAdvanceFlag, day, projectIdList);

        //先删后增
        LambdaQueryWrapper<SettledProBusinessEntity> lambdaFee = Wrappers.<SettledProBusinessEntity>lambdaQuery();
        if(CollectionUtils.isNotEmpty(projectIdList)){
            lambdaFee.in(SettledProBusinessEntity::getProjectId, projectIdList);
        }
        lambdaFee.eq(SettledProBusinessEntity::getReportingMonth, reportingMonth);
        settledProBusinessService.remove(lambdaFee);

        //查询项目信息数据
        List<SettledProBusinessVO> settledProBusinessVOList = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(projectIdList)){
            //如果projectList不为空，证明是修改数据，而不是生成数据
            settledProBusinessVOList = settledProBusinessMapper.queryProjectIds(projectIdList);
        }else{
            //等于1代表预生成数据
            settledProBusinessVOList = settledProBusinessMapper.queryProjectIds(null);
        }
        List<Long> projectIds = settledProBusinessVOList.stream().map(SettledProBusinessVO::getProjectId).collect(Collectors.toList());

        // 查询施工类合同
        List<SettledProBusinessVO> contractVOS = settledProBusinessMapper.queryContract(projectIds);
        Map<Long, SettledProBusinessVO> contractMap = new HashMap<>();
        if (CollectionUtils.isNotEmpty(contractVOS)) {
            contractMap = contractVOS.stream().collect(Collectors.toMap(x->x.getProjectId(), Function.identity(),(k1, k2) ->k2));
        }
        // 查询项目目标管理责任书
        List<SettledProBusinessVO> bookVOS = settledProBusinessMapper.queryBook(projectIds);
        Map<Long, SettledProBusinessVO> bookMap = new HashMap<>();
        if (CollectionUtils.isNotEmpty(bookVOS)) {
            bookMap = bookVOS.stream().collect(Collectors.toMap(x->x.getProjectId(), Function.identity(),(k1, k2) ->k2));
        }
        // 查询项目月度成本分析报告
        List<SettledProBusinessVO> costanalysisVOS = settledProBusinessMapper.queryCostanalysis(projectIds,reportingMonth);
        Map<Long, SettledProBusinessVO> costanalysisMap = new HashMap<>();
        if (CollectionUtils.isNotEmpty(costanalysisVOS)) {
            costanalysisMap = costanalysisVOS.stream().collect(Collectors.toMap(x->x.getProjectId(), Function.identity(),(k1, k2) ->k2));
        }
        // 查询总包结算定案会签表
        SettledProBusinessVO settlementFinalizedVO = settledProBusinessMapper.querySettlementFinalized(projectIds);
        // 查询目标责任书竣工考核兑现申报
        List<SettledProBusinessVO> applyVOS = settledProBusinessMapper.queryApply(projectIds);
        // 查询工程计量台账
        List<SettledProBusinessVO> engineermeasurementVOS = settledProBusinessMapper.queryEngineermeasurement(projectIds,reportingMonth);
        Map<Long, SettledProBusinessVO> engineermeasurementMap = new HashMap<>();
        if (CollectionUtils.isNotEmpty(engineermeasurementVOS)){
            engineermeasurementMap = engineermeasurementVOS.stream().collect(Collectors.toMap(x->x.getProjectId(), Function.identity(),(k1, k2) ->k2));
        }
        for (SettledProBusinessVO vo : settledProBusinessVOList) {
            vo.setReportingMonth(reportingMonth);
            Long projectId = vo.getProjectId();
            if (!contractMap.isEmpty() && contractMap.containsKey(projectId)) {
                vo.setPromoter(contractMap.get(projectId).getPromoter());
                vo.setPromoterName(contractMap.get(projectId).getPromoterName());
                vo.setProjectLocation(contractMap.get(projectId).getProjectLocation());
                vo.setContractSignTime(contractMap.get(projectId).getContractSignTime());
                vo.setContractStartDate(contractMap.get(projectId).getContractStartDate());
                vo.setContractEndDate(contractMap.get(projectId).getContractEndDate());
                vo.setContractAmount(CommonUtils.parseYuanToWanZ(contractMap.get(projectId).getContractAmount()));
                vo.setAcContractAmount(CommonUtils.parseYuanToWanZ(contractMap.get(projectId).getAcContractAmount()));
            }
            if (!bookMap.isEmpty() && bookMap.containsKey(projectId)) {
                vo.setUndertakeRate(bookMap.get(projectId).getUndertakeRate());
                vo.setTargetRate(bookMap.get(projectId).getTargetRate());
            }
            if (!costanalysisMap.isEmpty() && costanalysisMap.containsKey(projectId)) {
                vo.setContractIncome(CommonUtils.parseYuanToWanZ(costanalysisMap.get(projectId).getContractIncome()));
                vo.setAcContractIncome(CommonUtils.parseYuanToWanZ(costanalysisMap.get(projectId).getContractIncome()));
                vo.setRealCost(CommonUtils.parseYuanToWanZ(costanalysisMap.get(projectId).getRealCost()));
                vo.setAcRealCost(CommonUtils.parseYuanToWanZ(costanalysisMap.get(projectId).getRealCost()));
            }
            if (!engineermeasurementMap.isEmpty() && engineermeasurementMap.containsKey(projectId)) {
                vo.setSettlementAmount(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getSettlementAmount()));
                vo.setAcSettlementAmount(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getSettlementAmount()));
                vo.setContractReceivableMny(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getContractReceivableMny()));
                vo.setOperatingRevenue(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getOperatingRevenue()));
                vo.setRealRecrived(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getRealRecrived()));
            }
            if (settlementFinalizedVO != null) {
                vo.setSettlementFinalizeDate(settlementFinalizedVO.getCreateTime());
            }
            //补全二级组织信息
            CommonResponse<OrgVO> orgVo = orgApi.detailById(vo.getProjectDepartmentId());
            if (orgVo.isSuccess() && null != orgVo.getData()) {
                String innerCode = orgVo.getData().getInnerCode();
                String[] strs = innerCode.split("\\|");
                CommonResponse<OrgVO> orgVos = orgApi.detailById(Long.parseLong(strs[1]));
                if (orgVos.isSuccess() && null != orgVos.getData()) {
                    //二级组织信息
                    vo.setThreeOrgId(orgVos.getData().getId());
                    vo.setThreeOrgName(orgVos.getData().getName());
                }
            }
            if (vo.getFourOrgId() != null) {
                CommonResponse<OrgVO> fourOrgVO = orgApi.detailById(vo.getFourOrgId());
                if (fourOrgVO.isSuccess() && null != fourOrgVO.getData()) {
                    vo.setFourOrgName(fourOrgVO.getData().getName());// 股份公司四级单位
                }
            }
            if (vo.getContractorName() == null) {
                CommonResponse<OrgVO> orgVO = orgApi.detailById(vo.getContractor());
                if (orgVO.isSuccess() && null != orgVO.getData()) {
                    vo.setContractorName(orgVO.getData().getName());// 承包人名称
                }
            }
            // 结算周期（天数）
            vo.setSettlementCycleDays(ComputeUtil.safeDiv(new BigDecimal(vo.getSettlementFinalizeDate().getTime() - vo.getEndDate().getTime()), new BigDecimal(86400000)));
            // 利润率(%) = (结算额 - 实际成本)/结算额
            vo.setProfitRate(CommonUtils.calculateRate(ComputeUtil.safeSub(vo.getSettlementAmount(), vo.getRealCost()), vo.getSettlementAmount()));
            // 自施利润率(%) = (自施结算额 - 自施实际成本)
            vo.setAcProfitRate(CommonUtils.calculateRate(ComputeUtil.safeSub(vo.getAcSettlementAmount(), vo.getAcRealCost()), vo.getAcSettlementAmount()));
            if (vo.getAcProfitRate().compareTo(vo.getTargetRate()) == 1) {
                vo.setCompleteTargetBenefitFlag(1);
            }else {
                vo.setCompleteTargetBenefitFlag(0);
            }
            if (applyVOS.size() != 0) {
                vo.setCompleteExamineCashAuditFlag(1);
            } else {
                vo.setCompleteExamineCashAuditFlag(0);
            }
        }
        List<SettledProBusinessEntity> settledProBusinessEntityList = BeanMapper.mapList(settledProBusinessVOList, SettledProBusinessEntity.class);
        settledProBusinessService.saveBatch(settledProBusinessEntityList);
    }

    @Override
    public List<SettledProBusinessVO> dealData(List<SettledProBusinessVO> settledProBusinessVOS) {
        //处理第一行合计值
        SettledProBusinessVO settledProBusinessVO = new SettledProBusinessVO();
        ArrayList<SettledProBusinessVO> newList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(settledProBusinessVOS)) {
            getSumDate(settledProBusinessVOS, settledProBusinessVO);
            settledProBusinessVO.setNumber("合计");
            settledProBusinessVO.setId(IdWorker.getId());
            newList.add(settledProBusinessVO);
        }
        Integer number = 1;
        for (SettledProBusinessVO vo : settledProBusinessVOS) {
            vo.setNumber(String.valueOf(number));
            number++;
            switch (String.valueOf(vo.getProjectCategory())) {
                case "1470216164541710337":vo.setProjectCategoryName("工业厂房");break;
                case "1470216222511185922":vo.setProjectCategoryName("公共建筑");break;
                case "1470216274176622593":vo.setProjectCategoryName("民用住宅");break;
                case "1470216311648534530":vo.setProjectCategoryName("基础设施");break;
                case "1470216348239642626":vo.setProjectCategoryName("其它");break;
            }
            switch (vo.getCompleteTargetBenefitFlag()) {
                case 0:vo.setCompleteTargetBenefitFlagName("否");break;
                case 1:vo.setCompleteTargetBenefitFlagName("是");break;
            }
            switch (vo.getCompleteExamineCashAuditFlag()) {
                case 0:vo.setCompleteExamineCashAuditFlagName("否");break;
                case 1:vo.setCompleteExamineCashAuditFlagName("是");break;
            }
        }
        newList.addAll(settledProBusinessVOS);
        return newList;
    }

    private void getSumDate(List<SettledProBusinessVO> settledProBusinessVOS, SettledProBusinessVO settledProBusinessVO) {
        settledProBusinessVO.setContractAmount(settledProBusinessVOS.stream().filter(s -> s.getContractAmount() != null).map(SettledProBusinessVO::getContractAmount).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setAcContractAmount(settledProBusinessVOS.stream().filter(s -> s.getAcContractAmount() != null).map(SettledProBusinessVO::getAcContractAmount).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setContractIncome(settledProBusinessVOS.stream().filter(s -> s.getContractIncome() != null).map(SettledProBusinessVO::getContractIncome).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setAcContractIncome(settledProBusinessVOS.stream().filter(s -> s.getAcContractIncome() != null).map(SettledProBusinessVO::getAcContractIncome).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setRealCost(settledProBusinessVOS.stream().filter(s -> s.getRealCost() != null).map(SettledProBusinessVO::getRealCost).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setAcRealCost(settledProBusinessVOS.stream().filter(s -> s.getAcRealCost() != null).map(SettledProBusinessVO::getAcRealCost).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setContractReceivableMny(settledProBusinessVOS.stream().filter(s -> s.getContractReceivableMny() != null).map(SettledProBusinessVO::getContractReceivableMny).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setOperatingRevenue(settledProBusinessVOS.stream().filter(s -> s.getOperatingRevenue() != null).map(SettledProBusinessVO::getOperatingRevenue).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setRealRecrived(settledProBusinessVOS.stream().filter(s -> s.getRealRecrived() != null).map(SettledProBusinessVO::getRealRecrived).reduce(BigDecimal.ZERO, BigDecimal::add));
    }

}

==> ejc-analysis-impl-3.0.0-20230711.032208-47-sources.jar: com/ejianc/business/analysis/service/impl/SettledProBusinessServiceImpl.java <==
package com.ejianc.business.analysis.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.analysis.bean.UnsettledProBusinessEntity;
import com.ejianc.business.analysis.utils.CommonUtils;
import com.ejianc.business.analysis.vo.SettledProBusinessVO;
import com.ejianc.business.analysis.vo.UnsettledProBusinessVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ComputeUtil;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.analysis.mapper.SettledProBusinessMapper;
import com.ejianc.business.analysis.bean.SettledProBusinessEntity;
import com.ejianc.business.analysis.service.ISettledProBusinessService;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalTime;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.time.temporal.TemporalAdjusters;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 竣工已结算项目商务报表
 *
 * @author generator
 *
 */
@Service("settledProBusinessService")
public class SettledProBusinessServiceImpl extends BaseServiceImpl<SettledProBusinessMapper, SettledProBusinessEntity> implements ISettledProBusinessService{
    @Autowired
    private IOrgApi orgApi;
    @Autowired
    private ISettledProBusinessService settledProBusinessService;
    @Autowired
    private SettledProBusinessMapper settledProBusinessMapper;
    @Override
    public void execute(Integer inAdvanceFlag, String day, List<Long> projectIdList) {
        //获取查询数据的截止时间
        String reportingMonth = CommonUtils.getEndDate(inAdvanceFlag, day, projectIdList);

        //先删后增
        LambdaQueryWrapper<SettledProBusinessEntity> lambdaFee = Wrappers.<SettledProBusinessEntity>lambdaQuery();
        if(CollectionUtils.isNotEmpty(projectIdList)){
            lambdaFee.in(SettledProBusinessEntity::getProjectId, projectIdList);
        }
        lambdaFee.eq(SettledProBusinessEntity::getReportingMonth, reportingMonth);
        settledProBusinessService.remove(lambdaFee);

        //查询项目信息数据
        List<SettledProBusinessVO> settledProBusinessVOList = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(projectIdList)){
            //如果projectList不为空，证明是修改数据，而不是生成数据
            settledProBusinessVOList = settledProBusinessMapper.queryProjectIds(projectIdList);
        }else{
            //等于1代表预生成数据
            settledProBusinessVOList = settledProBusinessMapper.queryProjectIds(null);
        }
        List<Long> projectIds = settledProBusinessVOList.stream().map(SettledProBusinessVO::getProjectId).collect(Collectors.toList());

        // 查询施工类合同
        List<SettledProBusinessVO> contractVOS = settledProBusinessMapper.queryContract(projectIds);
        Map<Long, SettledProBusinessVO> contractMap = new HashMap<>();
        if (CollectionUtils.isNotEmpty(contractVOS)) {
            contractMap = contractVOS.stream().collect(Collectors.toMap(x->x.getProjectId(), Function.identity(),(k1, k2) ->k2));
        }
        // 查询项目目标管理责任书
        List<SettledProBusinessVO> bookVOS = settledProBusinessMapper.queryBook(projectIds);
        Map<Long, SettledProBusinessVO> bookMap = new HashMap<>();
        if (CollectionUtils.isNotEmpty(bookVOS)) {
            bookMap = bookVOS.stream().collect(Collectors.toMap(x->x.getProjectId(), Function.identity(),(k1, k2) ->k2));
        }
        // 查询项目月度成本分析报告
        List<SettledProBusinessVO> costanalysisVOS = settledProBusinessMapper.queryCostanalysis(projectIds,reportingMonth);
        Map<Long, SettledProBusinessVO> costanalysisMap = new HashMap<>();
        if (CollectionUtils.isNotEmpty(costanalysisVOS)) {
            costanalysisMap = costanalysisVOS.stream().collect(Collectors.toMap(x->x.getProjectId(), Function.identity(),(k1, k2) ->k2));
        }
        // 查询总包结算定案会签表
        SettledProBusinessVO settlementFinalizedVO = settledProBusinessMapper.querySettlementFinalized(projectIds);
        // 查询目标责任书竣工考核兑现申报
        List<SettledProBusinessVO> applyVOS = settledProBusinessMapper.queryApply(projectIds);
        // 查询工程计量台账
        List<SettledProBusinessVO> engineermeasurementVOS = settledProBusinessMapper.queryEngineermeasurement(projectIds,reportingMonth);
        Map<Long, SettledProBusinessVO> engineermeasurementMap = new HashMap<>();
        if (CollectionUtils.isNotEmpty(engineermeasurementVOS)){
            engineermeasurementMap = engineermeasurementVOS.stream().collect(Collectors.toMap(x->x.getProjectId(), Function.identity(),(k1, k2) ->k2));
        }
        for (SettledProBusinessVO vo : settledProBusinessVOList) {
            vo.setReportingMonth(reportingMonth);
            Long projectId = vo.getProjectId();
            if (!contractMap.isEmpty() && contractMap.containsKey(projectId)) {
                vo.setPromoter(contractMap.get(projectId).getPromoter());
                vo.setPromoterName(contractMap.get(projectId).getPromoterName());
                vo.setProjectLocation(contractMap.get(projectId).getProjectLocation());
                vo.setContractSignTime(contractMap.get(projectId).getContractSignTime());
                vo.setContractStartDate(contractMap.get(projectId).getContractStartDate());
                vo.setContractEndDate(contractMap.get(projectId).getContractEndDate());
                vo.setContractAmount(CommonUtils.parseYuanToWanZ(contractMap.get(projectId).getContractAmount()));
                vo.setAcContractAmount(CommonUtils.parseYuanToWanZ(contractMap.get(projectId).getAcContractAmount()));
            }
            if (!bookMap.isEmpty() && bookMap.containsKey(projectId)) {
                vo.setUndertakeRate(bookMap.get(projectId).getUndertakeRate());
                vo.setTargetRate(bookMap.get(projectId).getTargetRate());
            }
            if (!costanalysisMap.isEmpty() && costanalysisMap.containsKey(projectId)) {
                vo.setContractIncome(CommonUtils.parseYuanToWanZ(costanalysisMap.get(projectId).getContractIncome()));
                vo.setAcContractIncome(CommonUtils.parseYuanToWanZ(costanalysisMap.get(projectId).getContractIncome()));
                vo.setRealCost(CommonUtils.parseYuanToWanZ(costanalysisMap.get(projectId).getRealCost()));
                vo.setAcRealCost(CommonUtils.parseYuanToWanZ(costanalysisMap.get(projectId).getRealCost()));
            }
            if (!engineermeasurementMap.isEmpty() && engineermeasurementMap.containsKey(projectId)) {
                vo.setSettlementAmount(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getSettlementAmount()));
                vo.setAcSettlementAmount(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getSettlementAmount()));
                vo.setContractReceivableMny(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getContractReceivableMny()));
                vo.setOperatingRevenue(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getOperatingRevenue()));
                vo.setRealRecrived(CommonUtils.parseYuanToWanZ(engineermeasurementMap.get(projectId).getRealRecrived()));
            }
            if (settlementFinalizedVO != null) {
                vo.setSettlementFinalizeDate(settlementFinalizedVO.getCreateTime());
            }
            //补全二级组织信息
            CommonResponse<OrgVO> orgVo = orgApi.detailById(vo.getProjectDepartmentId());
            if (orgVo.isSuccess() && null != orgVo.getData()) {
                String innerCode = orgVo.getData().getInnerCode();
                String[] strs = innerCode.split("\\|");
                CommonResponse<OrgVO> orgVos = orgApi.detailById(Long.parseLong(strs[1]));
                if (orgVos.isSuccess() && null != orgVos.getData()) {
                    //二级组织信息
                    vo.setThreeOrgId(orgVos.getData().getId());
                    vo.setThreeOrgName(orgVos.getData().getName());
                }
            }
            if (vo.getFourOrgId() != null) {
                CommonResponse<OrgVO> fourOrgVO = orgApi.detailById(vo.getFourOrgId());
                if (fourOrgVO.isSuccess() && null != fourOrgVO.getData()) {
                    vo.setFourOrgName(fourOrgVO.getData().getName());// 股份公司四级单位
                }
            }
            if (vo.getContractorName() == null) {
                CommonResponse<OrgVO> orgVO = orgApi.detailById(vo.getContractor());
                if (orgVO.isSuccess() && null != orgVO.getData()) {
                    vo.setContractorName(orgVO.getData().getName());// 承包人名称
                }
            }
            // 结算周期（天数）
            vo.setSettlementCycleDays(ComputeUtil.safeDiv(new BigDecimal(vo.getSettlementFinalizeDate().getTime() - vo.getEndDate().getTime()), new BigDecimal(86400000)));
            // 利润率(%) = (结算额 - 实际成本)/结算额
            vo.setProfitRate(CommonUtils.calculateRate(ComputeUtil.safeSub(vo.getSettlementAmount()!=null?vo.getSettlementAmount():BigDecimal.ZERO, vo.getRealCost()!=null?vo.getRealCost():BigDecimal.ZERO), vo.getSettlementAmount()!=null?vo.getSettlementAmount():BigDecimal.ZERO));
            // 自施利润率(%) = (自施结算额 - 自施实际成本)
            vo.setAcProfitRate(CommonUtils.calculateRate(ComputeUtil.safeSub(vo.getAcSettlementAmount()!=null?vo.getAcSettlementAmount():BigDecimal.ZERO, vo.getAcRealCost()!=null?vo.getAcRealCost():BigDecimal.ZERO), vo.getAcSettlementAmount()!=null?vo.getAcSettlementAmount():BigDecimal.ZERO));
            if (vo.getAcProfitRate().compareTo(vo.getTargetRate()) == 1) {
                vo.setCompleteTargetBenefitFlag(1);
            }else {
                vo.setCompleteTargetBenefitFlag(0);
            }
            if (applyVOS.size() != 0) {
                vo.setCompleteExamineCashAuditFlag(1);
            } else {
                vo.setCompleteExamineCashAuditFlag(0);
            }
        }
        List<SettledProBusinessEntity> settledProBusinessEntityList = BeanMapper.mapList(settledProBusinessVOList, SettledProBusinessEntity.class);
        settledProBusinessService.saveBatch(settledProBusinessEntityList);
    }

    @Override
    public List<SettledProBusinessVO> dealData(List<SettledProBusinessVO> settledProBusinessVOS) {
        //处理第一行合计值
        SettledProBusinessVO settledProBusinessVO = new SettledProBusinessVO();
        ArrayList<SettledProBusinessVO> newList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(settledProBusinessVOS)) {
            getSumDate(settledProBusinessVOS, settledProBusinessVO);
            settledProBusinessVO.setNumber("合计");
            settledProBusinessVO.setId(IdWorker.getId());
            newList.add(settledProBusinessVO);
        }
        Integer number = 1;
        for (SettledProBusinessVO vo : settledProBusinessVOS) {
            vo.setNumber(String.valueOf(number));
            number++;
            switch (String.valueOf(vo.getProjectCategory())) {
                case "1470216164541710337":vo.setProjectCategoryName("工业厂房");break;
                case "1470216222511185922":vo.setProjectCategoryName("公共建筑");break;
                case "1470216274176622593":vo.setProjectCategoryName("民用住宅");break;
                case "1470216311648534530":vo.setProjectCategoryName("基础设施");break;
                case "1470216348239642626":vo.setProjectCategoryName("其它");break;
            }
            switch (vo.getCompleteTargetBenefitFlag()) {
                case 0:vo.setCompleteTargetBenefitFlagName("否");break;
                case 1:vo.setCompleteTargetBenefitFlagName("是");break;
            }
            switch (vo.getCompleteExamineCashAuditFlag()) {
                case 0:vo.setCompleteExamineCashAuditFlagName("否");break;
                case 1:vo.setCompleteExamineCashAuditFlagName("是");break;
            }
        }
        newList.addAll(settledProBusinessVOS);
        return newList;
    }

    private void getSumDate(List<SettledProBusinessVO> settledProBusinessVOS, SettledProBusinessVO settledProBusinessVO) {
        settledProBusinessVO.setContractAmount(settledProBusinessVOS.stream().filter(s -> s.getContractAmount() != null).map(SettledProBusinessVO::getContractAmount).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setAcContractAmount(settledProBusinessVOS.stream().filter(s -> s.getAcContractAmount() != null).map(SettledProBusinessVO::getAcContractAmount).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setContractIncome(settledProBusinessVOS.stream().filter(s -> s.getContractIncome() != null).map(SettledProBusinessVO::getContractIncome).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setAcContractIncome(settledProBusinessVOS.stream().filter(s -> s.getAcContractIncome() != null).map(SettledProBusinessVO::getAcContractIncome).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setRealCost(settledProBusinessVOS.stream().filter(s -> s.getRealCost() != null).map(SettledProBusinessVO::getRealCost).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setAcRealCost(settledProBusinessVOS.stream().filter(s -> s.getAcRealCost() != null).map(SettledProBusinessVO::getAcRealCost).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setContractReceivableMny(settledProBusinessVOS.stream().filter(s -> s.getContractReceivableMny() != null).map(SettledProBusinessVO::getContractReceivableMny).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setOperatingRevenue(settledProBusinessVOS.stream().filter(s -> s.getOperatingRevenue() != null).map(SettledProBusinessVO::getOperatingRevenue).reduce(BigDecimal.ZERO, BigDecimal::add));
        settledProBusinessVO.setRealRecrived(settledProBusinessVOS.stream().filter(s -> s.getRealRecrived() != null).map(SettledProBusinessVO::getRealRecrived).reduce(BigDecimal.ZERO, BigDecimal::add));
    }

}
